EvenVizion - is a video-based camera localization Python package.

By using this package you can create a pipeline which allows evaluating the relative positions of objects and translating the coordinates of an object (relative to the frame) into a fixed coordinate system. To determine the position of an object, the main task was set – the creation of a fixed coordinate system. To solve this, we created the EvenVizion component. We show that the task can be solved even in bad filming conditions (sharp camera movement, bad weather conditions, filming in the dark and so on).

More about the package structure, mathematical tools used and the explanation of visualization you can find in https://github.com/AIHunters/EvenVizion/blob/master/EvenVizion-video_based_camera_localization_component.pdf.

Installation
The most general installation is just to use pip, which should come with
any modern Python distribution.

::


    pip install evenvizion


Get the EvenVizion Source
If you prefer to download the source yourself


::

    git clone https://github.com/AIHunters/EvenVizion.git
    cd EvenVizion


Licence
EvenVizion is licensed under the MIT license, as found in the LICENSE file here: https://github.com/AIHunters/EvenVizion/blob/master/LICENSE.


Send us your failure cases and feedback!

Our project is open source and we will really appreciate getting your feedback!

For any kind of feedback or/and enquires you can contact us at oss@aihunters.com.

